@@ -168,8 +168,8 @@ static void auth_callback (const char *server_name, const char *share_name,
 #endif
 
 #ifdef DEBUG_SMB_LOCKS
-#define LOCK_SMB() 	{g_mutex_lock (smb_lock); g_print ("LOCK %s\n", G_GNUC_PRETTY_FUNCTION);}
-#define UNLOCK_SMB() 	{g_print ("UNLOCK %s\n", G_GNUC_PRETTY_FUNCTION); g_mutex_unlock (smb_lock);}
+#define LOCK_SMB() 	{g_mutex_lock (smb_lock); g_print ("LOCK %s\n", G_STRFUNC);}
+#define UNLOCK_SMB() 	{g_print ("UNLOCK %s\n", G_STRFUNC); g_mutex_unlock (smb_lock);}
 #else
 #define LOCK_SMB() 	g_mutex_lock (smb_lock)
 #define UNLOCK_SMB() 	g_mutex_unlock (smb_lock)
@@ -319,7 +319,7 @@ cache_reap_cb (void)
          * sure when we'll be called */
         if (!g_mutex_trylock (smb_lock))
                 return TRUE;
-        DEBUG_SMB(("LOCK %s\n", G_GNUC_PRETTY_FUNCTION));
+        DEBUG_SMB(("LOCK %s\n", G_STRFUNC));
 
 	size = g_hash_table_size (server_cache);
 	servers = g_ptr_array_sized_new (size);
@@ -441,10 +441,8 @@ remove_server  (gpointer key,
 		gpointer user_data)
 {
 	SmbServerCacheEntry *entry;
-	SMBCSRV *server;
 	
 	entry = key;
-	server = user_data;
 
 	if (entry->server == user_data) {
 		entry->server = NULL;
@@ -569,6 +567,7 @@ smb_uri_type (GnomeVFSURI *uri)
 {
 	GnomeVFSToplevelURI *toplevel;
 	char *first_slash;
+	char *host_name;
 
 	toplevel = (GnomeVFSToplevelURI *)uri;
 
@@ -589,11 +588,17 @@ smb_uri_type (GnomeVFSURI *uri)
 	    strcmp (uri->text, "/") == 0) {
 		/* smb://foo/ */
 		update_workgroup_cache ();
-		if (!g_ascii_strcasecmp(toplevel->host_name,
+		host_name = gnome_vfs_unescape_string (toplevel->host_name,
+		                                       G_DIR_SEPARATOR_S);
+		if (!host_name)
+			return SMB_URI_ERROR;
+		if (!g_ascii_strcasecmp(host_name,
 					DEFAULT_WORKGROUP_NAME) ||
-		    g_hash_table_lookup (workgroups, toplevel->host_name)) {
+		    g_hash_table_lookup (workgroups, host_name)) {
+			g_free (host_name);
 			return SMB_URI_WORKGROUP;
 		} else {
+			g_free (host_name);
 			return SMB_URI_SERVER;
 		}
 	}
@@ -601,11 +606,17 @@ smb_uri_type (GnomeVFSURI *uri)
 	if (first_slash == NULL) {
 		/* smb://foo/bar */
 		update_workgroup_cache ();
-		if (!g_ascii_strcasecmp(toplevel->host_name,
+		host_name = gnome_vfs_unescape_string (toplevel->host_name,
+		                                       G_DIR_SEPARATOR_S);
+		if (!host_name)
+			return SMB_URI_ERROR;
+		if (!g_ascii_strcasecmp(host_name,
 					DEFAULT_WORKGROUP_NAME) ||
-		    g_hash_table_lookup (workgroups, toplevel->host_name)) {
+		    g_hash_table_lookup (workgroups, host_name)) {
+			g_free (host_name);
 			return SMB_URI_SERVER_LINK;
 		} else {
+			g_free (host_name);
 			return SMB_URI_SHARE;
 		}
 	}
@@ -618,12 +629,27 @@ smb_uri_type (GnomeVFSURI *uri)
 static gboolean
 is_hidden_entry (char *name)
 {
-	if (name == NULL) return TRUE;
-
-	if (*(name + strlen (name) -1) == '$') return TRUE;
-
+	static const char *hidden_names[] = {
+		"IPC$",
+		"ADMIN$",
+		"print$",
+		"printer$"
+	};
+	
+	int i;
+	
+ 	if (name == NULL) return TRUE;
+ 
+	for (i = 0; i < G_N_ELEMENTS (hidden_names); i++)
+		if (g_ascii_strcasecmp (name, hidden_names[i]) == 0)
+			return TRUE;
+	
+	/* Shares that end in "$" are administrative shares, and Windows hides
+	 * them by default.  We have no way to say "this is a hidden file" in a
+	 * GnomeVFSFileInfo, so we'll make them visible for now.
+	 */
+	
 	return FALSE;
-
 }
 
 static gboolean
@@ -1533,7 +1559,7 @@ do_open (GnomeVFSMethod *method,
 
 	/* Important: perform_authentication leaves and re-enters the lock! */
 	while (perform_authentication (&actx) > 0) {
-		file = smb_context->open (smb_context, path, unix_mode, 0666);
+		file = (smb_context->open) (smb_context, path, unix_mode, 0666);
 		actx.res = (file != NULL) ? GNOME_VFS_OK : gnome_vfs_result_from_errno ();
 	}
 
@@ -1727,7 +1753,7 @@ do_create (GnomeVFSMethod *method,
 	
 	/* Important: perform_authentication leaves and re-enters the lock! */	
 	while (perform_authentication (&actx) > 0) {
-		file = smb_context->open (smb_context, path, unix_mode, perm);
+		file = (smb_context->open) (smb_context, path, unix_mode, perm);
 		actx.res = (file != NULL) ? GNOME_VFS_OK : gnome_vfs_result_from_errno ();
 	}
 
@@ -1842,6 +1868,8 @@ do_get_file_info (GnomeVFSMethod *method,
 	if (options & GNOME_VFS_FILE_INFO_GET_MIME_TYPE) {		
 		if (S_ISDIR(st.st_mode)) {
 			mime_type = "x-directory/normal";
+		} else if (options & GNOME_VFS_FILE_INFO_FORCE_SLOW_MIME_TYPE) {
+			mime_type = gnome_vfs_get_mime_type_common (uri);
 		} else {
 			mime_type = gnome_vfs_mime_type_from_name_or_default (file_info->name, NULL);
 		}
@@ -2056,6 +2084,7 @@ do_read_directory (GnomeVFSMethod *method,
 	struct stat st;
 	char *statpath;
 	char *path;
+	char *escaped;
 	int r = -1;
 	GList *l;
 
@@ -2150,17 +2179,20 @@ do_read_directory (GnomeVFSMethod *method,
 	case SMBC_DIR:
 	case SMBC_FILE:
 		path = dh->path;
-		
+		escaped = gnome_vfs_escape_string (file_info->name);
+
 		if (path[strlen(path)-1] == '/') {
 			statpath = g_strconcat (path, 
-						gnome_vfs_escape_string (file_info->name),
+						escaped,
 						NULL);
 		} else {
 			statpath = g_strconcat (path,
 						"/",
-						gnome_vfs_escape_string (file_info->name),
+						escaped,
 						NULL);
 		}
+		g_free (escaped);
+
 		/* TODO: might give an auth error, but should be rare due
 		   to the succeeding opendir. If this happens and we can't
 		   auth, we should terminate the readdir to avoid multiple
